@@ -56,7 +56,7 @@ sub new_client {
 		%fo = ();
 		return;
 	    };
-	    ( my $page = $1 ) =~s{%([\da-fA-F]{2})}{ chr(hex($1)) }sg; # urldecode
+	    ( my $page = $1 ) =~s{%([\da-fA-F]{2})}{ chr(hex($1)) }esg; # urldecode
 	    if ( ! eval { $fo{write}{buf} .= $response->($page,$addr,$hdr) } ) {
 		warn "creating response failed: $@\n";
 		%fo = ();
